% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Pattern.R
\name{as.character,Pattern-method}
\alias{as.character,Pattern-method}
\title{as.character.Pattern}
\usage{
\S4method{as.character}{Pattern}(x, ...)
}
\description{
as.character.Pattern
}
\keyword{internal}
