% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Tokens.R
\name{[,Tokens-method}
\alias{[,Tokens-method}
\title{index tokens}
\usage{
\S4method{[}{Tokens}(x, i, drop = TRUE)
}
\description{
index tokens
}
\keyword{internal}
