% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Tokens.R
\name{as.character,Tokens-method}
\alias{as.character,Tokens-method}
\title{to character}
\usage{
\S4method{as.character}{Tokens}(x, ...)
}
\description{
to character
}
\keyword{internal}
